@@ -19,11 +19,11 @@ Perl::Critic::Policy::CodeLayout::TabIndentSpaceAlign - Use tabs for indenting,
 
 =head1 VERSION
 
-Version 1.0.3
+Version 1.0.4
 
 =cut
 
-our $VERSION = '1.0.3';
+our $VERSION = '1.0.4';
 
 
 =head1 AFFILIATION
@@ -137,10 +137,10 @@ Check an element for violations against this policy.
 sub violates
 {
 	my ( $self, $element, undef ) = @_;
-	
+
 	# The __DATA__ element is exempt.
 	return if $element->parent->isa('PPI::Statement::Data');
-	
+
 	my $violations =
 	try
 	{
@@ -152,7 +152,7 @@ sub violates
 			my $content = $element->content();
 			$content =~ s/^[\r\n]+//;
 			$content =~ s/[\r\n]+$//;
-			
+
 			if ( $element->column_number() == 1 )
 			{
 				croak 'In comments and indentation, tabs are only allowed at the beginning of the string. Spaces are allowed but only after a non-space character.'
@@ -173,11 +173,11 @@ sub violates
 			my $declaration = $element->content();
 			croak 'The HereDoc declaration should not have any tabs.'
 				if $declaration =~ /\t/;
-			
+
 			# The content of the HereDoc block should behave like a multiline string.
 			my @heredoc = $element->heredoc();
 			croak 'Tabs are not allowed after non-tab characters.' if _has_violations_in_multiline_string( join( "\n", @heredoc ) );
-			
+
 			my $terminator = $element->terminator();
 			croak 'The HereDoc terminator should not have any tabs.'
 				if $terminator =~ /\t/;
@@ -188,20 +188,20 @@ sub violates
 			my $content = $element->content();
 			croak 'Tabs are not allowed after non-tab characters.' if _has_violations_in_multiline_string( $content );
 		}
-		
+
 		return;
 	}
 	catch
 	{
 		return $_;
 	};
-	
+
 	return $self->violation(
 		$DESCRIPTION,
 		$EXPLANATION,
 		$element,
 	) if defined( $violations ) && ( $violations ne '' );
-	
+
 	return;
 }
 
@@ -218,25 +218,20 @@ policy.
 sub _has_violations_in_multiline_string
 {
 	my ( $string ) = @_;
-	
+
 	foreach my $line ( split( /\r?\n/, $string ) )
 	{
 		# Don't allow tabs after non-tab characters on the same line.
 		# However, a tab followed by a space is legit, unlike the rest of the code.
 		next if $line !~ /[^\t]\t/;
-		
+
 		return 1;
 	}
-	
+
 	return 0;
 }
 
 
-=head1 AUTHOR
-
-Guillaume Aubert, C<< <aubertg at cpan.org> >>.
-
-
 =head1 BUGS
 
 Please report any bugs or feature requests through the web interface at
@@ -275,16 +270,21 @@ L<https://metacpan.org/release/Perl-Critic-Policy-CodeLayout-TabIndentSpaceAlign
 =back
 
 
+=head1 AUTHOR
+
+L<Guillaume Aubert|https://metacpan.org/author/AUBERTG>,
+C<< <aubertg at cpan.org> >>.
+
+
 =head1 ACKNOWLEDGEMENTS
 
-Thanks to ThinkGeek (L<http://www.thinkgeek.com/>) and its corporate overlords
-at Geeknet (L<http://www.geek.net/>), for footing the bill while I write code
-for them!
+I originally developed this project for ThinkGeek
+(L<http://www.thinkgeek.com/>). Thanks for allowing me to open-source it!
 
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2012-2013 Guillaume Aubert.
+Copyright 2012-2014 Guillaume Aubert.
 
 This program is free software: you can redistribute it and/or modify it under
 the terms of the GNU General Public License version 3 as published by the Free
